@@ -1083,8 +1083,10 @@ class Scope(object):
 
             return span
 
-    def continue_trace(self, environ_or_headers, op=None, name=None, source=None):
-        # type: (Dict[str, Any], Optional[str], Optional[str], Optional[str]) -> Transaction
+    def continue_trace(
+        self, environ_or_headers, op=None, name=None, source=None, origin="manual"
+    ):
+        # type: (Dict[str, Any], Optional[str], Optional[str], Optional[str], str) -> Transaction
         """
         Sets the propagation context from environment or headers and returns a transaction.
         """
@@ -1093,6 +1095,7 @@ class Scope(object):
         transaction = Transaction.continue_from_headers(
             normalize_incoming_data(environ_or_headers),
             op=op,
+            origin=origin,
             name=name,
             source=source,
         )
